badwing.characters package
==========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   badwing.characters.butterfly
   badwing.characters.robot
   badwing.characters.skeleton

Submodules
----------

badwing.characters.blob module
------------------------------

.. automodule:: badwing.characters.blob
   :members:
   :undoc-members:
   :show-inheritance:

badwing.characters.factory module
---------------------------------

.. automodule:: badwing.characters.factory
   :members:
   :undoc-members:
   :show-inheritance:

badwing.characters.pc module
----------------------------

.. automodule:: badwing.characters.pc
   :members:
   :undoc-members:
   :show-inheritance:

badwing.characters.skateboard module
------------------------------------

.. automodule:: badwing.characters.skateboard
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: badwing.characters
   :members:
   :undoc-members:
   :show-inheritance:
